PROC GLOBAL

set explicit

numeric minlat maxlat minlong maxlong xlat xlong mindi cln dd err ss;

PROC GPS_FF
preproc
{ !!! UPDATE THESE VALUES FOR YOUR COUNTRY !!! }
minlat = -39;       { minimum latitude in the country - negative = South, positive = North }
maxlat = 44;        { maximum latitude in the country - negative = South, positive = North }
minlong = -70;      { minimum longitude in the country - negative = West, positive = East }
maxlong = 79;       { maximum longitude in the country - negative = West, positive = East }
mindi = 20051201;   { earliest interview date in yyyymmdd format } 

PROC GP1
{ check cluster is in the sample file }
recode GP1      => err;
       101-148  => 0;    { Give list of valid cluster numbers }
       201-248  => 0;
       301-348  => 0;
       401-448  => 0;
       501-548  => 0;
       601-648  => 0;
       701-748  => 0;
       801-848  => 0;
       901-916  => 0;
                => 1;
endrecode;
if err then
  display("   ");
  reenter;
endif;

PROC GP2
{ !!! ENTER CORRESPONDENCE BETWEEN CLUSTER AND AREA FOR YOUR COUNTRY !!! }
recode GP1  : GP2 => err;
    101-124         :  1  => 0;
    125-148         :  2  => 0;
    201-213         :  1  => 0;
    214,226-248     :  2  => 0;
    301-324         :  1  => 0;
    325-348         :  2  => 0;
    401-423,437     :  1  => 0;
    424-436,438-448 :  2  => 0;
    501-520,531-534 :  1  => 0;   
    521-530,535-548 :  2  => 0;
    604-627         :  1  => 0;   
    601-603,628-648 :  2  => 0;
    701-723,735     :  1  => 0;   
    724-734,736-748 :  2  => 0;
    701-848,901-914 :  1  => 0;   
    915,916         :  2  => 0;
                    :     => 1;
endrecode;
if err then
  display("  ");
  reenter
endif;

PROC GP3
{ !!! ENTER CORRESPONDENCE BETWEEN CLUSTER AND REGION FOR YOUR COUNTRY !!! }
recode GP1  : GP3 => err;
    101-148 :  1  => 0;
    201-248 :  2  => 0;
    301-348 :  3  => 0;
    401-448 :  4  => 0;
    501-548 :  5  => 0;
    601-648 :  6  => 0;
    701-748 :  7  => 0;
    801-848 :  8  => 0;
    901-916 :  9  => 0;
            :     => 1;
endrecode;
if err then
  display("  ");
  reenter
endif;

PROC GP5Y
recode GP5Y  :     GP5M        : GP5D => err;
   2005-2006 : 1,3,5,7,8,10,12 : 1-31 => 0;
   2005-2006 : 4,6,9,11        : 1-30 => 0;
   2005-2006 : 2               : 1-28 => 0;
             :                 :      => 1;
endrecode;
if err then
  display("  ");
  reenter
endif;
dd = (GP5Y*100 + GP5M)*100 + GP5D;
ss = sysdate("yyyymmdd");
if dd >= ss or dd < mindi then
	  display("dd=%d; ss=%d",dd,ss);
  {display("Date of interview impossible");}
  reenter
endif;

PROC GP7NS
{if GP7NS <> "n" & GP7NS <> "N" & GP7NS <> "s" & GP7NS <> "S" then
  display("         .");
  reenter;
endif;}

GP7NS = "N" ;
PROC GP7D
if GP7NS = "N" then
  xlat = GP7D;
elseif GP7NS = "S" then
  xlat = (0-GP7D);
endif;  
if not xlat in minlat:maxlat then
  if maxlat < 0 then
    display("      (%dS:%dS)",(0-minlat),(0-maxlat));
  elseif minlat < 0 then
    display("      (%dS:%dN)",(0-minlat),maxlat);
  else  
    display("      (%dN:%dN)",minlat,maxlat);
  endif;
endif;

PROC GP8EW
{if GP8EW <> "e" & GP8EW <> "E" & GP8EW <> "w" & GP8EW <> "W" then
  display("         .");
  reenter;
endif;}

GP8EW = "E" ;
PROC GP8D
if GP8EW = "E" then
  xlong = GP8D;
elseif GP8EW = "W" then
  xlong = (0-GP8D);
endif;  
if not xlong in minlong:maxlong then
  if maxlong < 0 then
    display("      (%dW:%dW)",(0-minlong),(0-maxlong));
  elseif minlong < 0 then
    display("      (%dW:%dE)",(0-minlong),maxlong);
  else  
    display("      (%dE:%dE)",minlong,maxlong);
  endif;
endif;

PROC DP6
if DP6 <> GP6 then
  display("   !   ");
  DP6 = "";
  reenter;
endif;

PROC DP7NS
{if DP7NS <> GP7NS then
  display("   !   ");
  DP7NS = "";
  reenter;
endif;}

DP7NS = "N" ;
PROC DP7D
if DP7D <> GP7D then
  display("   !   ");
  DP7D = 0;
  reenter;
endif;

PROC DP8EW
{if DP8EW <> GP8EW then
  display("   !   ");
  DP8EW = "";
  reenter;
endif;}

DP8EW = "E" ;
PROC DP8D
if DP8D <> GP8D then
  display("   !   ");
  DP8D = 0;
  reenter;
endif;

